@@ -1,5 +1,6 @@
 import argparse
 import asyncio
+import logging
 import os
 import sys
 import time
@@ -18,16 +19,18 @@ from vectorcode import __version__
 from vectorcode.cli_utils import (
     CliAction,
     Config,
+    config_logging,
     find_project_root,
     load_config_file,
     parse_cli_args,
 )
 from vectorcode.common import get_client, get_collection, try_server
 from vectorcode.subcommands.ls import get_collection_list
-from vectorcode.subcommands.query import get_query_result_files
+from vectorcode.subcommands.query import build_query_results
 
 cached_project_configs: dict[str, Config] = {}
 DEFAULT_PROJECT_ROOT: str | None = None
+logger = logging.getLogger(__name__)
 
 
 async def make_caches(project_root: str):
@@ -67,7 +70,9 @@ server: LanguageServer = LanguageServer(name="vectorcode-server", version=__vers
 async def execute_command(ls: LanguageServer, args: list[str]):
     global DEFAULT_PROJECT_ROOT
     start_time = time.time()
+    logger.info("Received command arguments: %s", args)
     parsed_args = await parse_cli_args(args)
+    logger.info("Parsed command arguments: %s", parsed_args)
     if parsed_args.action not in {CliAction.query, CliAction.ls}:
         print(
             f"Unsupported vectorcode subcommand: {str(parsed_args.action)}",
@@ -75,27 +80,33 @@ async def execute_command(ls: LanguageServer, args: list[str]):
         )
         return
     if parsed_args.project_root is None:
-        assert DEFAULT_PROJECT_ROOT is not None, (
-            "Failed to automatically resolve project root!"
-        )
-
-        parsed_args.project_root = DEFAULT_PROJECT_ROOT
+        if DEFAULT_PROJECT_ROOT is not None:
+            parsed_args.project_root = DEFAULT_PROJECT_ROOT
+            logger.warning("Using DEFAULT_PROJECT_ROOT: %s", DEFAULT_PROJECT_ROOT)
     elif DEFAULT_PROJECT_ROOT is None:
+        logger.warning("Updating DEFAULT_PROJECT_ROOT to %s", parsed_args.project_root)
         DEFAULT_PROJECT_ROOT = str(parsed_args.project_root)
 
-    parsed_args.project_root = os.path.abspath(str(parsed_args.project_root))
-    await make_caches(parsed_args.project_root)
-    final_configs = await cached_project_configs[parsed_args.project_root].merge_from(
-        parsed_args
-    )
-    final_configs.pipe = True
+    if parsed_args.project_root is not None:
+        parsed_args.project_root = os.path.abspath(str(parsed_args.project_root))
+        await make_caches(parsed_args.project_root)
+        final_configs = await cached_project_configs[
+            parsed_args.project_root
+        ].merge_from(parsed_args)
+        final_configs.pipe = True
+        client = await get_client(final_configs)
+        collection = await get_collection(
+            client=client,
+            configs=final_configs,
+            make_if_missing=final_configs.action in {CliAction.vectorise},
+        )
+    else:
+        final_configs = parsed_args
+        client = await get_client(parsed_args)
+        collection = None
+    logger.info("Merged final configs: %s", final_configs)
     progress_token = str(uuid.uuid4())
-    client = await get_client(final_configs)
-    collection = await get_collection(
-        client=client,
-        configs=final_configs,
-        make_if_missing=final_configs.action in {CliAction.vectorise},
-    )
+
     await ls.progress.create_async(progress_token)
     match final_configs.action:
         case CliAction.query:
@@ -107,26 +118,20 @@ async def execute_command(ls: LanguageServer, args: list[str]):
                 ),
             )
             final_results = []
-            for path in await get_query_result_files(
-                collection=collection,
-                configs=final_configs,
-            ):
-                if os.path.isfile(path):
-                    with open(path) as fin:
-                        output_path = path
-                        if not final_configs.use_absolute_path:
-                            output_path = os.path.relpath(
-                                path, final_configs.project_root
-                            )
-                        final_results.append(
-                            {"path": output_path, "document": fin.read()}
-                        )
-            ls.progress.end(
-                progress_token,
-                types.WorkDoneProgressEnd(
-                    message=f"Retrieved {len(final_results)} result{'s' if len(final_results) > 1 else ''} in {round(time.time() - start_time, 2)}s."
-                ),
-            )
+            try:
+                if collection is None:
+                    print("Please specify a project to search in.", file=sys.stderr)
+                else:
+                    final_results.extend(
+                        await build_query_results(collection, final_configs)
+                    )
+            finally:
+                log_message = f"Retrieved {len(final_results)} result{'s' if len(final_results) > 1 else ''} in {round(time.time() - start_time, 2)}s."
+                ls.progress.end(
+                    progress_token,
+                    types.WorkDoneProgressEnd(message=log_message),
+                )
+                logger.info(log_message)
             return final_results
         case CliAction.ls:
             ls.progress.begin(
@@ -136,12 +141,15 @@ async def execute_command(ls: LanguageServer, args: list[str]):
                     message="Looking for other projects indexed by VectorCode",
                 ),
             )
-            projects: list[dict] = await get_collection_list(client)
-
-            ls.progress.end(
-                progress_token,
-                types.WorkDoneProgressEnd(message="List retrieved."),
-            )
+            projects: list[dict] = []
+            try:
+                projects.extend(await get_collection_list(client))
+            finally:
+                ls.progress.end(
+                    progress_token,
+                    types.WorkDoneProgressEnd(message="List retrieved."),
+                )
+                logger.info(f"Retrieved {len(projects)} project(s).")
             return projects
 
 
@@ -159,12 +167,19 @@ async def lsp_start() -> int:
     else:
         DEFAULT_PROJECT_ROOT = os.path.abspath(args.project_root)
 
+    if DEFAULT_PROJECT_ROOT is None:
+        logger.warning("DEFAULT_PROJECT_ROOT is empty.")
+    else:
+        logger.info(f"{DEFAULT_PROJECT_ROOT=}")
+
+    logger.info("Parsed LSP server CLI arguments: %s", args)
     await asyncio.to_thread(server.start_io)
 
     return 0
 
 
 def main():  # pragma: nocover
+    config_logging("vectorcode-lsp-server", stdio=False)
     asyncio.run(lsp_start())
 
 
