@@ -98,16 +98,56 @@ def test_get_embedding_function_init_exception():
 
 
 @pytest.mark.asyncio
-async def test_try_server():
-    # This test requires a server to be running, so it's difficult to make it truly isolated.
-    # For now, let's just check that it returns False when the server is not running on a common port.
-    assert not await try_server("localhost", 9999)
+async def test_try_server_versions():
+    # Test successful v1 response
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_response = MagicMock()
+        mock_response.status_code = 200
+        mock_client.return_value.__aenter__.return_value.get.return_value = (
+            mock_response
+        )
+        assert await try_server("localhost", 8300) is True
+        mock_client.return_value.__aenter__.return_value.get.assert_called_once_with(
+            url="http://localhost:8300/api/v1/heartbeat"
+        )
 
+    # Test fallback to v2 when v1 fails
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_response_v1 = MagicMock()
+        mock_response_v1.status_code = 404
+        mock_response_v2 = MagicMock()
+        mock_response_v2.status_code = 200
+        mock_client.return_value.__aenter__.return_value.get.side_effect = [
+            mock_response_v1,
+            mock_response_v2,
+        ]
+        assert await try_server("localhost", 8300) is True
+        assert mock_client.return_value.__aenter__.return_value.get.call_count == 2
 
-@pytest.mark.asyncio
-async def test_wait_for_server_timeout():
-    with pytest.raises(TimeoutError):
-        await wait_for_server("localhost", 9999, timeout=1)
+    # Test both versions fail
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_response_v1 = MagicMock()
+        mock_response_v1.status_code = 404
+        mock_response_v2 = MagicMock()
+        mock_response_v2.status_code = 500
+        mock_client.return_value.__aenter__.return_value.get.side_effect = [
+            mock_response_v1,
+            mock_response_v2,
+        ]
+        assert await try_server("localhost", 8300) is False
+
+    # Test connection error cases
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_client.return_value.__aenter__.return_value.get.side_effect = (
+            httpx.ConnectError("Cannot connect")
+        )
+        assert await try_server("localhost", 8300) is False
+
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_client.return_value.__aenter__.return_value.get.side_effect = (
+            httpx.ConnectTimeout("Connection timeout")
+        )
+        assert await try_server("localhost", 8300) is False
 
 
 @pytest.mark.asyncio
@@ -346,25 +386,34 @@ async def test_get_collection_hnsw():
 
 @pytest.mark.asyncio
 async def test_start_server():
-    # Mock subprocess.Popen
-    with (
-        patch("asyncio.create_subprocess_exec") as MockCreateProcess,
-        patch("asyncio.sleep"),
-        patch("socket.socket") as MockSocket,
-        patch("vectorcode.common.wait_for_server") as MockWaitForServer,
-    ):
-        # Mock socket to return a specific port
-        mock_socket = MagicMock()
-        mock_socket.getsockname.return_value = ("localhost", 12345)  # Mock port
-        MockSocket.return_value.__enter__.return_value = mock_socket
+    with tempfile.TemporaryDirectory() as temp_dir:
 
-        # Mock the process object
-        mock_process = MagicMock()
-        mock_process.returncode = 0  # Simulate successful execution
-        MockCreateProcess.return_value = mock_process
+        def _new_isdir(path):
+            if str(temp_dir) in str(path):
+                return True
+            return False
 
-        # Create a config object
-        with tempfile.TemporaryDirectory() as temp_dir:
+        # Mock subprocess.Popen
+        with (
+            patch("asyncio.create_subprocess_exec") as MockCreateProcess,
+            patch("asyncio.sleep"),
+            patch("socket.socket") as MockSocket,
+            patch("vectorcode.common.wait_for_server") as MockWaitForServer,
+            patch("os.path.isdir") as mock_isdir,
+            patch("os.makedirs") as mock_makedirs,
+        ):
+            mock_isdir.side_effect = _new_isdir
+            # Mock socket to return a specific port
+            mock_socket = MagicMock()
+            mock_socket.getsockname.return_value = ("localhost", 12345)  # Mock port
+            MockSocket.return_value.__enter__.return_value = mock_socket
+
+            # Mock the process object
+            mock_process = MagicMock()
+            mock_process.returncode = 0  # Simulate successful execution
+            MockCreateProcess.return_value = mock_process
+
+            # Create a config object
             config = Config(
                 host="localhost",
                 port=8000,
@@ -390,7 +439,7 @@ async def test_start_server():
                 "--path",
                 temp_dir,
                 "--log-path",
-                os.path.join(temp_dir, "chroma.log"),
+                os.path.join(str(config.db_log_path), "chroma.log"),
             ]
             assert args[0] == sys.executable
             assert tuple(args[1:]) == tuple(expected_args[1:])
@@ -398,11 +447,10 @@ async def test_start_server():
             assert kwargs["stderr"] == sys.stderr
             assert "ANONYMIZED_TELEMETRY" in kwargs["env"]
 
-            # Assert that wait_for_server was called with the correct arguments
             MockWaitForServer.assert_called_once_with("localhost", 12345)
 
-            # Assert that the function returns the process
             assert process == mock_process
+            mock_makedirs.assert_called_once_with(config.db_log_path)
 
 
 @pytest.mark.asyncio
@@ -476,11 +524,29 @@ def test_get_embedding_function_fallback():
 
 
 @pytest.mark.asyncio
-async def test_wait_for_server_request_error():
-    # Mocking httpx.AsyncClient to raise a RequestError
-    with patch("httpx.AsyncClient") as mock_client:
-        mock_client.return_value.__aenter__.return_value.get.side_effect = (
-            httpx.RequestError("Simulated request error")
-        )
-        with pytest.raises(TimeoutError):
-            await wait_for_server("localhost", 9999, timeout=1)
+async def test_wait_for_server_success():
+    # Mock try_server to return True immediately
+    with patch("vectorcode.common.try_server") as mock_try_server:
+        mock_try_server.return_value = True
+
+        # Should complete immediately without timeout
+        await wait_for_server("localhost", 8000, timeout=1)
+
+        # Verify try_server was called once
+        mock_try_server.assert_called_once_with("localhost", 8000)
+
+
+@pytest.mark.asyncio
+async def test_wait_for_server_timeout():
+    # Mock try_server to always return False
+    with patch("vectorcode.common.try_server") as mock_try_server:
+        mock_try_server.return_value = False
+
+        # Should raise TimeoutError after 0.1 seconds (minimum timeout)
+        with pytest.raises(TimeoutError) as excinfo:
+            await wait_for_server("localhost", 8000, timeout=0.1)
+
+        assert "Server did not start within 0.1 seconds" in str(excinfo.value)
+
+        # Verify try_server was called multiple times (due to retries)
+        assert mock_try_server.call_count > 1
