@@ -122,6 +122,54 @@ async def test_execute_command_query(mock_language_server, mock_config):
         mock_language_server.progress.end.assert_called()
 
 
+@pytest.mark.asyncio
+async def test_execute_command_query_default_proj_root(
+    mock_language_server, mock_config
+):
+    with (
+        patch(
+            "vectorcode.lsp_main.parse_cli_args", new_callable=AsyncMock
+        ) as mock_parse_cli_args,
+        patch("vectorcode.lsp_main.get_client", new_callable=AsyncMock),
+        patch("vectorcode.lsp_main.get_collection", new_callable=AsyncMock),
+        patch(
+            "vectorcode.lsp_main.build_query_results", new_callable=AsyncMock
+        ) as mock_get_query_result_files,
+        patch("os.path.isfile", return_value=True),
+        patch("vectorcode.lsp_main.try_server", return_value=True),
+        patch("builtins.open", MagicMock()) as mock_open,
+        patch("vectorcode.lsp_main.cached_project_configs", {}),
+    ):
+        from vectorcode.lsp_main import cached_project_configs
+
+        global DEFAULT_PROJECT_ROOT
+
+        mock_config.project_root = None
+        cached_project_configs.clear()
+        mock_parse_cli_args.return_value = mock_config
+        mock_get_query_result_files.return_value = ["/test/file.txt"]
+
+        # Configure the MagicMock object to return a string when read() is called
+        mock_file = MagicMock()
+        mock_file.__enter__.return_value.read.return_value = "{}"  # Return valid JSON
+        mock_open.return_value = mock_file
+
+        # Ensure parsed_args.project_root is not None
+        DEFAULT_PROJECT_ROOT = "/test/project"
+
+        # Add a mock config to cached_project_configs
+        cached_project_configs["/test/project"] = mock_config
+
+        # Mock the merge_from method
+        mock_config.merge_from = AsyncMock(return_value=mock_config)
+
+        result = await execute_command(mock_language_server, ["query", "test"])
+
+        assert isinstance(result, list)
+        mock_language_server.progress.begin.assert_called()
+        mock_language_server.progress.end.assert_called()
+
+
 @pytest.mark.asyncio
 async def test_execute_command_ls(mock_language_server, mock_config):
     mock_config.action = CliAction.ls
